@@ -11,7 +11,7 @@ def create_model(file_path, endpoint, token, data):
     uploaded_filename, content = read_file(file_path)
     url = f"{base_url}/training/{endpoint}"
     files = {'file': (uploaded_filename, content)}
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data, files=files, headers=headers)
@@ -40,11 +40,19 @@ def model_deployment(project_id,model_id,token):
         "model_id": model_id
         }
 
-        url = f"{base_url}/training/deployment"
-        access_token = 'Bearer '+ {token}
+        deployment_url = f"{base_url}/training/deployment"
+        model_select = f"{base_url}training/model-selector"
+        access_token = 'Bearer '+ token
         headers = {"Authorization": access_token}
         # Send the POST request
-        response = requests.post(url, data=data, headers=headers)
+        response = requests.post(deployment_url, data=data, headers=headers)
+        #
+        data2 = {
+            "deployment_id": response.json()['deployment_id'],
+            "model_id":model_id
+        }
+        #updating ds file folder with model id for running visualizer directly 
+        requests.post(model_select, data=data2, headers=headers)
         return response.json()
     except:
         return "manual model has no deployment"
@@ -55,7 +63,7 @@ def model_deployment(project_id,model_id,token):
 
 def get_training_result(project_id,token):
     url = f"{base_url}/training/get-results/{project_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.get(url, headers=headers)
     response_json=response.json()
@@ -71,7 +79,7 @@ def get_holdout_result(project_id,model_id,token):
     }
 
     url = f"{base_url}/training/model-results"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.post(url,headers=headers,data=data)
     return response.json()
@@ -79,7 +87,7 @@ def get_holdout_result(project_id,model_id,token):
 
 def get_projectdetails(app_id,token):
     url = f"{base_url}/training/project-details/{app_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
@@ -87,7 +95,7 @@ def get_projectdetails(app_id,token):
 
 def get_jobdetails(app_id,token):
     url = f"{base_url}/training/job-details?app_id={app_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
@@ -100,7 +108,7 @@ def json_check(response):
 
 def get_blueprint(deployment_id,token):
     url = f"{base_url}/training/blueprint"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     data = {
         "deployment_id" : deployment_id
@@ -110,42 +118,42 @@ def get_blueprint(deployment_id,token):
 
 def get_deploymentdetails(deployment_id,token):
     url = f"{base_url}/training/deployment/{deployment_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return json_check(response)
     
 def get_project_details(project,token):
     url = f"{base_url}/training/project/{project}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return json_check(response)
 
 def delete_deployment(deployment_id,token):
     url = f"{base_url}/training/deployment/{deployment_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.delete(url,headers=headers)
     return json_check(response)
 
 def delete_multiple_deployment(project_id,token):
     url = f"{base_url}/training/deployment-details/{project_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.delete(url,headers=headers)
     return json_check(response)
 
 def delete_project(project,token):
     url = f"{base_url}/training/project/{project}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.delete(url,headers=headers)
     return json_check(response)
 
 def update_deployment(deployment_id,model_id,token):
     url = f"{base_url}/training/deployment/{deployment_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     data = {
         "model_id":model_id
