@@ -1,5 +1,5 @@
 import requests
-from ..config import base_url, api_token
+from ..config import base_url,api_token
 
 # Creates an account  Organization/Client
 def create_account(name,email,username,password):
@@ -15,13 +15,14 @@ def create_account(name,email,username,password):
     return response.text
 
 
-def create_app(name,client_id):
+def create_app(name,client_id,access_token):
     data = {
     "name": name,                  
     "client": client_id  
     }
     url = f"{base_url}/app/"
-    headers = {"Authorization":api_token}
+    access_token = "Bearer "+ access_token
+    headers = {"Authorization": access_token}
     response = requests.post(url,json=data,headers=headers)
     return response.json()
 
@@ -35,5 +36,8 @@ def login(username,password):
     headers = {"Authorization":api_token}
     response = requests.post(url,json=data,headers=headers)
     output = response.json()
-    del output["refresh"]
+    try:
+        del output["refresh"]
+    except:
+        return response.json()
     return output
